Documentation
¶
Index ¶
- type Configuration
- type ServerConfiguration
- func (c *ServerConfiguration) Cert() string
- func (c *ServerConfiguration) Key() string
- func (c *ServerConfiguration) Mux() *http.ServeMux
- func (c *ServerConfiguration) Path() string
- func (c *ServerConfiguration) Port() int
- func (c *ServerConfiguration) Protocol() string
- func (c *ServerConfiguration) Server() *http.Server
- func (c *ServerConfiguration) TLS() bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration interface {
Cert() string
Key() string
Port() int
Path() string
Protocol() string
Server() *http.Server
Mux() *http.ServeMux
TLS() bool
}
func NewConfiguration ¶
func NewConfiguration(cert, key, path string, port int) Configuration
Creates a new configuration to be used in the server.
type ServerConfiguration ¶
type ServerConfiguration struct {
// contains filtered or unexported fields
}
Configuration for the executor server.
func (*ServerConfiguration) Cert ¶
func (c *ServerConfiguration) Cert() string
Gets the path to the TLS certificate.
func (*ServerConfiguration) Key ¶
func (c *ServerConfiguration) Key() string
Gets the path to the TLS key.
func (*ServerConfiguration) Mux ¶
func (c *ServerConfiguration) Mux() *http.ServeMux
Returns the internal HTTP server's handler that's used for routing.
func (*ServerConfiguration) Path ¶
func (c *ServerConfiguration) Path() string
Returns the path that specifies where the executor is located on the host.
func (*ServerConfiguration) Port ¶
func (c *ServerConfiguration) Port() int
Returns the port that the server listens on.
func (*ServerConfiguration) Protocol ¶
func (c *ServerConfiguration) Protocol() string
Determines the protocol to be used.
func (*ServerConfiguration) Server ¶
func (c *ServerConfiguration) Server() *http.Server
Returns the internal HTTP server.
func (*ServerConfiguration) TLS ¶
func (c *ServerConfiguration) TLS() bool
If a TLS certificate and key have been provided then TLS is enabled.
Click to show internal directories.
Click to hide internal directories.